@@ -33,6 +33,11 @@
         <source>Share</source>
         <translation>Compartir</translation>
     </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="10"/>
+        <source>Change icon</source>
+        <translation>Cambiar icono</translation>
+    </message>
     <message>
         <location filename="../mainwindow.cpp" line="10"/>
         <source>Compress</source>
@@ -838,7 +843,7 @@
     </message>
     <message>
         <location filename="../unzipdlg.cpp" line="10"/>
-        <source>Keep existing files</source>
+                    <source>Keep existing files</source>
         <translation>Mantener archivos existentes</translation>
     </message>
     <message>
@@ -903,4 +908,12 @@
         <translation>Admin de archivos para Maemo 5</translation>
     </message>
 </context>
+<context>
+    <name>selectIcon</name>
+    <message>
+        <location filename="../selecticon.cpp" line="10"/>
+        <source>Select icon</source>
+        <translation>Seleccione icono</translation>
+    </message>
+</context>
 </TS>
