@@ -33,6 +33,11 @@
         <source>Share</source>
         <translation>Dela</translation>
     </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="10"/>
+        <source>Change icon</source>
+        <translation>Ändra ikon</translation>
+    </message>
     <message>
         <location filename="../mainwindow.cpp" line="10"/>
         <source>Compress</source>
@@ -903,4 +908,12 @@
         <translation>Filhanterare för Maemo 5</translation>
     </message>
 </context>
+<context>
+    <name>selectIcon</name>
+    <message>
+        <location filename="../selecticon.cpp" line="10"/>
+        <source>Select icon</source>
+        <translation>Välj ikon</translation>
+    </message>
+</context>
 </TS>
